# -*- coding: utf-8 -*-
from datetime import datetime, timedelta

DATE_MASK = '%Y/%m/%d %H'
DATETIME_HOUR_MASK = '%Y/%m/%d %H:%M'
DATETIME_MASK = '%Y/%m/%d %H:%M:%S'
REE_END_DATE = '30000101'
REE_END_DATE_HOUR = '3000/01/01 01'
SIMPLE_DATE_MASK = '%Y%m%d'

# Since v41 of SIMEL specifications
CUPSDAT_CPUS45_REE_END_DATE_HOUR = '3000/01/01 00'